==> bitkub-0.0.2.tar.gz: bitkub-0.0.2/bitkub/constants.py <==
ENDPOINTS = {
    "API_ROOT": "https://api.bitkub.com",
    "STATUS_PATH": "/api/status",
    "SERVERTIME_PATH": "/api/servertime",
    "MARKET_SYMBOLS_PATH": "/api/market/symbols",
    "MARKET_TICKER_PATH": "/api/market/ticker",
    "MARKET_TRADES_PATH": "/api/market/trades",
    "MARKET_BIDS_PATH": "/api/market/bids",
    "MARKET_ASKS_PATH": "/api/market/asks",
    "MARKET_BOOKS_PATH": "/api/market/books",
    "MARKET_TRADING_VIEW_PATH": "/api/market/trading-view",
    "MARKET_DEPTH_PATH": "/api/market/depth",
    "MARKET_WALLET": "/api/merket/wallet",
    "MARKET_BALANCES": "/api/merket/balances",
    "MARKET_PLACE_BID": "/api/merket/place-bid",
    "MARKET_PLACE_ASK": "/api/merket/place-ask",
    "MARKET_PLACE_ASK_BY_FIAT": "/api/merket/place-ask-by-fiat",
    "MARKET_CANCEL_ORDER": "/api/merket/cancel-order",
    "MARKET_MY_OPEN_ORDERS": "/api/merket/my-open-orders",
    "MARKET_MY_ORDER_HISTORY": "/api/merket/my-order-history",
    "MARKET_ORDER_INFO": "/api/merket/order-info",
    "CRYPTO_ADDRESSES": "/api/crypto/addresses",
    "CRYPTO_WITHDRAW": "/api/crypto/withdraw",
    "CRYPTO_DEPOSIT_HISTORY": "/api/crypto/deposit-history",
    "CRYPTO_WITHDRAW_HISTORY": "/api/crypto/withdraw-history",
    "FIAT_ACCOUNTS": "/api/fiat/accounts",
    "FIAT_WITHDRAW": "/api/fiat/withdraw",
    "FIAT_DEPOSIT_HISTORY": "/api/fiat/deposit-history",
    "FIAT_WITHDRAW_HISTORY": "/api/fiat/withdraw-history",
    "MARKET_WSTOKEN": "/api/merket/wstoken",
    "USER_LIMITS": "/api/user/limits",
    "USER_TRADING_CREDITS": "/api/user/trading-credits",
}

==> bitkub-0.1.0.tar.gz: bitkub-0.1.0/bitkub/constants.py <==
ENDPOINTS = {
    "API_ROOT": "https://api.bitkub.com",
    "STATUS_PATH": "/api/status",
    "SERVERTIME_PATH": "/api/servertime",
    "MARKET_SYMBOLS_PATH": "/api/market/symbols",
    "MARKET_TICKER_PATH": "/api/market/ticker?sym={sym}",
    "MARKET_TRADES_PATH": "/api/market/trades?sym={sym}&lmt={lmt}",
    "MARKET_BIDS_PATH": "/api/market/bids?sym={sym}&lmt={lmt}",
    "MARKET_ASKS_PATH": "/api/market/asks?sym={sym}&lmt={lmt}",
    "MARKET_BOOKS_PATH": "/api/market/books?sym={sym}&lmt={lmt}",
    "MARKET_TRADING_VIEW_PATH": "/api/market/tradingview?sym={sym}&int={int}&frm={frm}&to={to}",
    "MARKET_DEPTH_PATH": "/api/market/depth?sym={sym}&lmt={lmt}",
    "MARKET_WALLET": "/api/merket/wallet",
    "MARKET_BALANCES": "/api/merket/balances",
    "MARKET_PLACE_BID": "/api/merket/place-bid",
    "MARKET_PLACE_ASK": "/api/merket/place-ask",
    "MARKET_PLACE_ASK_BY_FIAT": "/api/merket/place-ask-by-fiat",
    "MARKET_CANCEL_ORDER": "/api/merket/cancel-order",
    "MARKET_MY_OPEN_ORDERS": "/api/merket/my-open-orders",
    "MARKET_MY_ORDER_HISTORY": "/api/merket/my-order-history",
    "MARKET_ORDER_INFO": "/api/merket/order-info",
    "CRYPTO_ADDRESSES": "/api/crypto/addresses",
    "CRYPTO_WITHDRAW": "/api/crypto/withdraw",
    "CRYPTO_DEPOSIT_HISTORY": "/api/crypto/deposit-history",
    "CRYPTO_WITHDRAW_HISTORY": "/api/crypto/withdraw-history",
    "FIAT_ACCOUNTS": "/api/fiat/accounts",
    "FIAT_WITHDRAW": "/api/fiat/withdraw",
    "FIAT_DEPOSIT_HISTORY": "/api/fiat/deposit-history",
    "FIAT_WITHDRAW_HISTORY": "/api/fiat/withdraw-history",
    "MARKET_WSTOKEN": "/api/merket/wstoken",
    "USER_LIMITS": "/api/user/limits",
    "USER_TRADING_CREDITS": "/api/user/trading-credits",
}
